@@ -23,7 +23,7 @@ use     List::MoreUtils       qw( any                         );
 use     Data::UUID            qw( NameSpace_DNS               );
 require Devel::StackTrace;
 
-use version; $VERSION = version->new('0.184')->numify;
+use version; $VERSION = version->new('0.185')->numify;
 
 #>>>
 
@@ -286,7 +286,8 @@ sub trace_line {
 	if ( $tracestate_status >= 100 ) {
 		$tracestate_status -= 100;
 		$tracestate_test = 1;
-		require Test::More;
+
+#		require Test::More;
 	}
 
 	# Short-circuit.
@@ -295,16 +296,19 @@ sub trace_line {
 	$no_display = 0 unless defined $no_display;
 
 	my $stack = Devel::StackTrace->new();
-
+	my $index = 1;
+	my $frame = $stack->frame(1);
+	while ( $frame->subroutine() =~ m/trace_line/sm ) {
+		$frame = $stack->frame( ++$index );
+	}
 	my $string =
 	  $self->_trace_line( $tracelevel, $text, $no_display,
-		$tracestate_status, $stack->frame(1) );
+		$tracestate_status, $frame );
 
 	if ($tracestate_test) {
-		Test::More::diag("$string");
+		print "$string";
 	} elsif ( $tracelevel == 0 ) {
-		## no critic 'RequireBracedFileHandleWithPrint'
-		print STDERR "$string";
+		print {*STDERR} "$string";
 	} else {
 		print "$string";
 	}
@@ -383,13 +387,12 @@ sub generate_guid {
 		$sitename_guid =
 		  $guidgen->create_from_name( Data::UUID::NameSpace_DNS,
 			$sitename );
+		$self->trace_line( 5,
+			    'Generated site GUID: '
+			  . $guidgen->to_string($sitename_guid)
+			  . "\n" );
 	}
 
-	$self->trace_line( 5,
-		    'Generated site GUID: '
-		  . $guidgen->to_string($sitename_guid)
-		  . "\n" );
-
 	#... then use it to create a GUID out of the filename.
 	return uc $guidgen->create_from_name_str( $sitename_guid, $id );
 
